@@ -18,18 +18,13 @@ import typing as ty
 
 from osc_lib.command import command
 
-if ty.TYPE_CHECKING:
-    from osc_lib import shell
-
 
 class Timing(command.Lister):
     """Show timing data"""
 
-    app: 'shell.OpenStackShell'
-
     def take_action(
         self, parsed_args: argparse.Namespace
-    ) -> ty.Tuple[ty.Tuple[str, ...], ty.List[ty.Any]]:
+    ) -> tuple[tuple[str, ...], list[ty.Any]]:
         column_headers = (
             'URL',
             'Seconds',
