@@ -48,7 +48,7 @@ DEFAULT_DOMAIN = 'default'
 DEFAULT_INTERFACE = 'public'
 
 
-def prompt_for_password(prompt: ty.Optional[str] = None) -> str:
+def prompt_for_password(prompt: str | None = None) -> str:
     """Prompt user for a password
 
     Prompt for a password if stdin is a tty.
@@ -82,19 +82,18 @@ class OpenStackShell(app.App):
     client_manager: clientmanager.ClientManager
 
     log = logging.getLogger(__name__)
-    timing_data: ty.List[ty.Any] = []
+    timing_data: list[ty.Any] = []
 
     def __init__(
         self,
-        description: ty.Optional[str] = None,
-        version: ty.Optional[str] = None,
-        command_manager: ty.Optional[commandmanager.CommandManager] = None,
-        stdin: ty.Optional[ty.TextIO] = None,
-        stdout: ty.Optional[ty.TextIO] = None,
-        stderr: ty.Optional[ty.TextIO] = None,
-        interactive_app_factory: ty.Optional[
-            ty.Type['interactive.InteractiveApp']
-        ] = None,
+        description: str | None = None,
+        version: str | None = None,
+        command_manager: commandmanager.CommandManager | None = None,
+        stdin: ty.TextIO | None = None,
+        stdout: ty.TextIO | None = None,
+        stderr: ty.TextIO | None = None,
+        interactive_app_factory: type['interactive.InteractiveApp']
+        | None = None,
         deferred_help: bool = False,
     ) -> None:
         # Patch command.Command to add a default auth_required = True
@@ -127,7 +126,7 @@ class OpenStackShell(app.App):
         # Set in subclasses
         self.api_version = None
 
-        self.command_options: ty.List[str] = []
+        self.command_options: list[str] = []
 
         self.do_profile = False
 
@@ -136,7 +135,7 @@ class OpenStackShell(app.App):
         self.log_configurator = logs.LogConfigurator(self.options)
         self.dump_stack_trace = self.log_configurator.dump_trace
 
-    def run(self, argv: ty.List[str]) -> int:
+    def run(self, argv: list[str]) -> int:
         ret_val = 1
         self.command_options = argv
         try:
@@ -180,7 +179,7 @@ class OpenStackShell(app.App):
                 f"osprofiler trace show --html {trace_id} "
             )
 
-    def run_subcommand(self, argv: ty.List[str]) -> int:
+    def run_subcommand(self, argv: list[str]) -> int:
         self.init_profile()
         try:
             ret_value = super().run_subcommand(argv)
@@ -198,9 +197,9 @@ class OpenStackShell(app.App):
 
     def build_option_parser(
         self,
-        description: ty.Optional[str],
-        version: ty.Optional[str],
-        argparse_kwargs: ty.Optional[ty.Dict[str, ty.Any]] = None,
+        description: str | None,
+        version: str | None,
+        argparse_kwargs: dict[str, ty.Any] | None = None,
     ) -> _argparse.ArgumentParser:
         parser = super().build_option_parser(
             description,
@@ -416,7 +415,7 @@ class OpenStackShell(app.App):
         """
         pass
 
-    def initialize_app(self, argv: ty.List[str]) -> None:
+    def initialize_app(self, argv: list[str]) -> None:
         """Global app init bits:
 
         * set up API versions
@@ -471,9 +470,6 @@ class OpenStackShell(app.App):
             "cloud cfg: %s", strutils.mask_password(self.cloud.config)
         )
 
-        # Callout for stuff between o-c-c and ClientManager
-        # self._initialize_app_2(self.options)
-
         self._load_plugins()
 
         self._load_commands()
@@ -532,7 +528,7 @@ class OpenStackShell(app.App):
         self,
         cmd: 'command.Command',
         result: int,
-        err: ty.Optional[BaseException],
+        err: BaseException | None,
     ) -> None:
         self.log.debug('clean_up %s: %s', cmd.__class__.__name__, err or '')
 
@@ -570,7 +566,7 @@ class OpenStackShell(app.App):
             tcmd.run(targs)
 
 
-def main(argv: ty.Optional[ty.List[str]] = None) -> int:
+def main(argv: list[str] | None = None) -> int:
     if argv is None:
         argv = sys.argv[1:]
     return OpenStackShell().run(argv)
